"""
Various constant values

KST 20140903
"""

import os

# path information of the package
PYMRIO_PATH = {
    "root": os.path.dirname(__file__),
    "test_mrio": os.path.abspath(
        os.path.join(os.path.dirname(__file__), "../mrio_models/test_mrio")
    ),
    "testmrio": os.path.abspath(
        os.path.join(os.path.dirname(__file__), "../mrio_models/test_mrio")
    ),
    "test": os.path.abspath(
        os.path.join(os.path.dirname(__file__), "../mrio_models/test_mrio")
    ),
    "exio20": os.path.abspath(
        os.path.join(os.path.dirname(__file__), "../mrio_models/exio20")
    ),
    "exio2": os.path.abspath(
        os.path.join(os.path.dirname(__file__), "../mrio_models/exio20")
    ),
}

# generic names (needed for the aggregation  if no names are given)
GENERIC_NAMES = {
    "sector": "sec",
    "region": "reg",
    "iosys": "IOSystem",
    "ext": "Extension",
}

DEFAULT_FILE_NAMES = {"filepara": "file_parameters.json", "metadata": "metadata.json"}

MISSING_AGG_ENTRY = {
    "region": "Unspecified region",
    "sector": "Unspecified sector",
}



from setuptools import find_packages, setup

exec(open("pymrio/version.py").read())

setup(
    name="pymrio",
    description=(
        "A python module for automating input output "
        "calculations and generating reports"
    ),
    long_description=open("README.rst").read(),
    url="https://github.com/konstantinstadler/pymrio",
    author="Konstantin Stadler",
    author_email="konstantin.stadler@ntnu.no",
    version=__version__,  # noqa
    packages=find_packages(),
    include_package_data=True,
    python_requires=">=3.7.0",
    package_data={
        "": ["*.txt", "*.dat", "*.doc", "*.rst", "*.json"],
    },
    # This some needs to be here and in requirments.txt (for conda)
    install_requires=[
        "pandas >= 0.25.0",
        "matplotlib >= 2.0.0",
        "requests >= 2.18",
        "numpy >= 1.13.4",
        "xlrd >= 1.1.0",
    ],
    classifiers=[
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3 :: Only",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Development Status :: 4 - Beta",
        "Environment :: Console",
        "Intended Audience :: End Users/Desktop",
        "Intended Audience :: Developers",
        "Intended Audience :: Science/Research",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
        "Operating System :: POSIX",
        "Programming Language :: Python",
        "Topic :: Scientific/Engineering",
        "Topic :: Utilities",
    ],
)
